#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 csv
version:              0.1.2
visibility:           public
id:                   csv-0.1.2-8kEiO6xJBbxEErgQB8bTyl
key:                  csv-0.1.2-8kEiO6xJBbxEErgQB8bTyl
license:              MIT
copyright:            Jaap Weel, 2007
maintainer:           Jaap Weel <weel@ugcs.caltech.edu>
author:               Jaap Weel <weel@ugcs.caltech.edu>
synopsis:             CSV loader and dumper
description:
    CSV loader and dumper

    This library parses and dumps documents that are formatted
    according to RFC 4180, \"The common Format and MIME Type for
    Comma-Separated Values (CSV) Files\". This format is used, among
    many other things, as a lingua franca for spreadsheets, and for
    certain web services.

category:             Text
abi:                  5e15c533f18bcf408f53a8822f2f9176
exposed:              True
exposed-modules:      Text.CSV
import-dirs:          /usr/lib/ghc-8.10.5/site-local/csv-0.1.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/csv-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/csv-0.1.2
hs-libraries:         HScsv-0.1.2-8kEiO6xJBbxEErgQB8bTyl
depends:              base-4.14.2.0 filepath-1.4.2.1 parsec-3.1.14.0
haddock-interfaces:   /usr/share/doc/haskell-csv/html/csv.haddock
haddock-html:         /usr/share/doc/haskell-csv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

